@@ -618,6 +618,7 @@ size_stack (bb)
 }
 
 #ifndef HAVE_STRDUP
+#ifndef __linux__
 char *
 strdup (str)
      const char *str;
@@ -628,6 +629,7 @@ strdup (str)
   strcpy (ret, str);
   return ret;
 }
+#endif /* not __linux__ */
 #endif
 
 #ifndef _DEBUG_MALLOC_INC
@@ -731,6 +733,7 @@ strincmp (s1, s2, n)
 
 #ifndef _DEBUG_MALLOC_INC
 #ifndef HAVE_STRSTR
+#ifndef __linux__
 #ifdef __STDC__
 char *
 strstr (const char *s, const char *wanted)
@@ -757,6 +760,7 @@ strstr (s, wanted)
       return (char *) 0;
   return scan;
 }
+#endif /* not __linux__ */
 #endif
 #endif /* ndef _DEBUG_MALLOC_INC */
 
